@@ -1,19 +1,7 @@
-import matplotlib
 from matplotlib import pylab
 import numpy
 
-'''
-Create dummy matplotlib plot for use in testing the module svg_compression
-Written: JULY 22, 2014
-Author Gen Del Raye
-'''
-
-matplotlib.rcParams['svg.fonttype'] = 'none' # Embed text instead of turning text to paths
-
 def square_factory(x, y, h, ax, color = 'red'):
-    '''
-    Add squares to plot
-    '''
     left = x - 0.5*h
     right = x + 0.5*h
     bottom = y - 0.5*h
@@ -22,9 +10,6 @@ def square_factory(x, y, h, ax, color = 'red'):
     ax.fill_between(x, y1 = top, y2 = bottom, color = color)
 
 def circle_factory(x, y, r, ax, color = 'blue'):
-    '''
-    Add circles to plot
-    '''
     circle = pylab.Circle((x, y), r, color = color)
     ax.add_patch(circle)
 
